@@ -62,7 +62,7 @@ FancyPlotterSettings::FancyPlotterSettings( QWidget* parent, bool locked )
   page = new QFrame();
   addPage( page, i18n( "General" ) );
   pageLayout = new QGridLayout( page );
-  pageLayout->setMargin( 0 );
+  pageLayout->setContentsMargins( 0, 0, 0, 0 );
 
   label = new QLabel( i18n( "Title:" ), page );
   pageLayout->addWidget( label, 0, 0 );
@@ -82,7 +82,7 @@ FancyPlotterSettings::FancyPlotterSettings( QWidget* parent, bool locked )
   page = new QFrame();
   addPage( page, i18n( "Scales" ) );
   pageLayout = new QGridLayout( page );
-  pageLayout->setMargin( 0 );
+  pageLayout->setContentsMargins( 0, 0, 0, 0 );
 
   groupBox = new QGroupBox( i18n( "Vertical scale" ), page );
   boxLayout = new QGridLayout;
@@ -135,7 +135,7 @@ FancyPlotterSettings::FancyPlotterSettings( QWidget* parent, bool locked )
   page = new QFrame( );
   addPage( page, i18n( "Grid" ) );
   pageLayout = new QGridLayout( page );
-  pageLayout->setMargin( 0 );
+  pageLayout->setContentsMargins( 0, 0, 0, 0 );
 
   groupBox = new QGroupBox( i18n( "Lines" ), page );
   boxLayout = new QGridLayout;
@@ -193,7 +193,7 @@ FancyPlotterSettings::FancyPlotterSettings( QWidget* parent, bool locked )
   page = new QFrame( );
   addPage( page, i18n( "Sensors" ) );
   pageLayout = new QGridLayout( page );
-  pageLayout->setMargin( 0 );
+  pageLayout->setContentsMargins( 0, 0, 0, 0 );
   pageLayout->setRowStretch( 2, 1 );
   pageLayout->setRowStretch( 5, 1 );
 
